@@ -5,15 +5,19 @@ from typing import Any, Callable, NoReturn, Dict
 from pathlib import Path
 from unicodedata import normalize
 from imghdr import what
+from subprocess import run
+from platform import system
 
 from aiohttp import request
 from ujson import dumps, loads
 from pybase64 import b64encode
 from aiofiles import open as aiopen
 
+from ..setup import __version__
 from .enums import MediaType
 from .exceptions import SmallReasonForBan
 
+
 headers = {
     'NDCDEVICEID': '0146BD6CF162E40F7449AFF316BA524DDDE1A1C4E6D99A553F3472EC3F4CB2F6A9ED05E5100492DC76'
 }
@@ -25,6 +29,9 @@ bot_id = None
 Req_json = Dict[str, Any]
 
 
+def clear():
+    run('cls' if system() == 'Windows' else 'clear', shell=True)
+
 def exist(d: Req_json, k: str, *, in_str: bool = True):
     try:
         return str(d[k]) if in_str else d[k]
@@ -188,7 +195,7 @@ class Message:
 
         com = actual_com or com
         chat = actual_chat or chat
-        files = [files] if not isinstance(files, (tuple, list)) else files
+        files = [files] if files and not isinstance(files, (tuple, list)) else files
 
         if msgs:
             data = await self._CreateData.msg(type_, msgs)
@@ -362,6 +369,16 @@ class File:
 
 
 class Chat:
+    __slots__ = ('id',
+                 'is_private',
+                 'name')
+
+    def __init__(self, j=None):
+        if j:
+            self.id = exist(j, 'threadId')
+            self.is_private = exist(j, 'membersQuota') == 2
+            self.name = exist(j, 'title')
+
     async def messages(
         self,
         *,
